@@ -32,6 +32,9 @@ def dowloadcape(username, file_pach: None):
         if(file_pach == None):
             print("no file pach")
             exit()
+        if("." in file_pach):
+            print("file pach only. no files like /coolcape.png")
+            exit()
         else:
             
             image = requests.get(f"https://api.capes.dev/load/{username}/minecraft").json()
